@@ -1,5 +1,5 @@
 from ..utils import Games
-from .ultimates import ultimates
+#from .ultimates import ultimates
 
 
 
@@ -19,7 +19,7 @@ class Bedwars:
 		self.solo = Solo(data)
 		self.duo = Duo(data)
 		self.trio = Trio(data)
-		self.quad = Quad(data)
+		self.squad = Squad(data)
 		
 		#Games
 		self.games = Games(
@@ -162,10 +162,10 @@ class Trio:
 			data.get("player", {}).get("stats", {}).get("Bedwars", {}).get("four_threee_emerald_resources_collected_bedwars", 0)
 			)
 
-class Quad:
+class Squad:
 	
 	def __init__(self, data):
-		self.name = "Trios"
+		self.name = "Squad"
 
 		#Games
 		self.games = Games(
