@@ -1,4 +1,4 @@
-import requests
+import aiohttp
 import asyncio
 import json
 
@@ -16,7 +16,7 @@ class get_player:
 		self.api = api
 
 
-	def get(self, name=None, uuid=None):
+	async def get(self, name=None, uuid=None):
 
 		if name == None and uuid == None:
 			raise NoInputError
@@ -26,9 +26,9 @@ class get_player:
 			if uuid == None:
 				uuid = get_uuid(name)
 
-
-		response = requests.get(f"{HYPIXEL_API}/player?key={self.api}&uuid={uuid}")
-		json = response.json()
+		async with aiohttp.ClientSession() as client:
+			async with client.get(f"{HYPIXEL_API}/player?key={self.api}&uuid={uuid}") as response:
+				json = await response.json()
 
 		if not json["success"]:
 
